@@ -13,9 +13,7 @@ def get_ecses():
     cli = ali_cli.AliCli(cfg.get('config', 'accesskeyid'),
                          cfg.get('config', 'accesskeysecret'),
                          cfg.get('config', 'regionids').split(','))
-    ecses= [ecs for ecs in cli.ecses_iterator()]
-    ecses = sorted(ecses, key=lambda x: x.hostname, reverse=False)
-    return ecses
+    return [ecs for ecs in cli.ecses_iterator()]
 
 
 @click.command()
@@ -25,7 +23,7 @@ def cli():
         try:
             os.system('clear')
             for i in range(len(ecses)):
-                print(''.join([str(i + 1), ' :', ecses[i].__str__()]))
+                print(''.join([str(i + 1), ':', ecses[i].__str__()]))
 
             indexstr = input('请选择ECS序号:')
             if not isinstance(indexstr, int):
